"""
A python client for the Expensify API
"""

__version__ = "0.1.0"
__author__ = "Alex Lazich"

from .client import ExpensifyClient